#
# This is the SPEC file for creating binary and source RPMs for the Dom0.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#

Name:		qubes-gui-daemon
Version:	4.3.7
Release:	1%{dist}
Summary:	The Qubes GUI virtualization

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org

Requires:	xorg-x11-server-Xorg
Requires:	service(graphical-login)
Requires:	libconfig
Requires:	python%{python3_pkgversion}-xcffib
Requires:	qubes-utils >= 4.2.10
Requires:	qubes-core-qrexec >= 4.1.5
Requires:	python%{python3_pkgversion}-qubesimgconverter >= 4.1.4
Requires:	socat
Requires:	group(qubes)
Requires:   (%{name}-selinux if selinux-policy)

BuildRequires:	python%{python3_pkgversion}-devel
BuildRequires:	python%{python3_pkgversion}-setuptools
BuildRequires:	pulseaudio-libs-devel
BuildRequires:	pkgconfig(x11)
BuildRequires:	pkgconfig(x11-xcb)
BuildRequires:	pkgconfig(xcb)
BuildRequires:	pkgconfig(xcb-aux)
BuildRequires:	pkgconfig(xcb-shm)
BuildRequires:	libXrandr-devel
BuildRequires:	libconfig-devel
BuildRequires:	libpng-devel
BuildRequires:	libnotify-devel
BuildRequires:	xen-devel
BuildRequires:	qubes-db-devel
BuildRequires:	help2man
BuildRequires:	gcc
BuildRequires:	qubes-core-libs-devel >= 1.6.1
BuildRequires:	qubes-core-libs
BuildRequires:	qubes-gui-common-devel >= 4.3.0
BuildRequires:	qubes-libvchan-xen-devel
BuildRequires:	qubes-utils-devel >= 4.2.10
BuildRequires:  selinux-policy-devel

Source0: %{name}-%{version}.tar.gz

%description
The Qubes GUI virtualization infrastructure that needs to be installed in GuiVM.

%package -n qubes-gui-dom0
Summary:    Dom0 part of Qubes GUI
# For now require also gui-daemon in dom0, when dropping GUI in dom0, this
# dependency should be dropped
Requires:   qubes-gui-daemon
# Pull also audio packages for easier upgrade
Requires:   qubes-audio-daemon
Requires:   qubes-audio-dom0
Requires:	qubes-core-dom0 >= 4.1.1
# for policy.EvalSimple service
Requires:	qubes-core-qrexec-dom0 >= 4.1.14
Requires:   python%{python3_pkgversion}-setuptools

%description -n qubes-gui-dom0
Dom0 files for Qubes GUI virtualization. This include core-admin extension,
policy files etc.

%package -n qubes-audio-daemon
Summary:	The Qubes AUDIO virtualization
Requires:	pulseaudio-libs
%if 0%{?fedora} >= 35
Requires:	pulseaudio-daemon
%else
Requires:	pulseaudio
%endif
Requires:	libconfig
Requires:   qubes-utils >= 3.1.0
Requires:   python%{python3_pkgversion}-pydbus

%description -n qubes-audio-daemon
The Qubes AUDIO virtualization infrastructure that needs to be installed in AudioVM.

%package -n qubes-audio-dom0
Summary:    Dom0 part of Qubes AUDIO
Requires:	qubes-core-dom0 >= 1.3.14
Requires:   python%{python3_pkgversion}-setuptools

%description -n qubes-audio-dom0
Dom0 files for Qubes AUDIO virtualization. This include core-admin extension,
policy files etc.

%package selinux

BuildRequires: selinux-policy
%{?selinux_requires}

Summary: SELinux policy for qubes-gui-daemon
License: GPLv2+

%description selinux
SELinux policy for qubes-gui-daemon.  You need this package to run qubes-guid
on a system where SELinux is in enforcing mode.

%post selinux
%selinux_modules_install %{_datadir}/selinux/packages/qubes-gui-daemon.pp || :

%postun selinux
if [ "$1" -eq 0 ]; then
    %selinux_modules_uninstall %{_datadir}/selinux/packages/qubes-gui-daemon.pp
fi || :

%posttrans selinux
%selinux_relabel_post
exit 0

%prep
%setup -q

%build
%{?set_build_flags}
make clean
make all all-selinux BACKEND_VMM=xen

%py3_build

%pre

%install
rm -rf $RPM_BUILD_ROOT
%make_install
make install-selinux DESTDIR=$RPM_BUILD_ROOT
%py3_install

%triggerin -- xorg-x11-server-Xorg
ln -sf /usr/bin/X-wrapper-qubes /usr/bin/X

%postun
if [ "$1" = 0 ] ; then
	# no more packages left
    ln -sf /usr/bin/Xorg /usr/bin/X
fi

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}

%files
%defattr(-,root,root,-)
%attr(4750,root,qubes) /usr/bin/qubes-guid
%{_mandir}/man1/qubes-guid.1.gz
/usr/bin/X-wrapper-qubes
%{_libdir}/qubes-gui-daemon/shmoverride.so
%config(noreplace) %{_sysconfdir}/qubes/guid.conf
/etc/xdg/autostart/qubes-screen-layout-watches.desktop
/etc/xdg/autostart/qubes-icon-receiver.desktop
/etc/X11/xinit/xinitrc.d/qubes-localgroup.sh
/usr/libexec/qubes/watch-screen-layout-changes
/usr/libexec/qubes/wrappers/Xwayland
/usr/lib/qubes/icon-receiver
%config %{_sysconfdir}/qubes-rpc/qubes.WindowIconUpdater
%config %{_sysconfdir}/qubes/rpc-config/qubes.WindowIconUpdater

%files -n qubes-audio-daemon
/usr/bin/pacat-simple-vchan

%files -n qubes-gui-dom0
%config(noreplace) %{_sysconfdir}/qubes/policy.d/90-default-gui-daemon.policy

%files -n qubes-audio-dom0
%{python3_sitelib}/qubesguidaemon-*.egg-info
%{python3_sitelib}/qubesguidaemon

%files selinux
%{_datadir}/selinux/packages/qubes-gui-daemon.pp

%changelog
* Tue Dec 10 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-gui-daemon.git

* Tue Dec 10 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ced89d2
- version 4.3.7

* Fri Dec 06 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 97c9e36
- audio: fix reacting on mic enable/disable requests

* Fri Nov 29 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 11703f4
- version 4.3.6

* Fri Nov 22 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 62c9112
- Leave defining _FORTIFY_SOURCE to distribution policy

* Sun Nov 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7f440ea
- version 4.3.5

* Tue Nov 12 2024 Ali Mirjamali <ali@mirjamali.com> - 0e85ffe
- Add `_NET_WM_PING` support

* Tue Nov 12 2024 Ali Mirjamali <ali@mirjamali.com> - 43326d1
- Add `_NET_WM_NAME` & `_NET_WM_ICON_NAME` support

* Fri Nov 08 2024 Ali Mirjamali <ali@mirjamali.com> - debadbc
- Handle `disable` & `none` for secure copy/paste

* Mon Oct 28 2024 Aaron Rainbolt <arraybolt3@ubuntu.com> - 0d83229
- Add event buffering for cloaking user input patterns

* Mon Oct 28 2024 Aaron Rainbolt <arraybolt3@ubuntu.com> - 3a74c63
- Replace magic quotes with normal quotes in parse_vm_config

* Mon Oct 28 2024 Aaron Rainbolt <arraybolt3@ubuntu.com> - b91c757
- Typo fix, change "canot" to "cannot"

* Sun Oct 27 2024 qubest <qubest.dev@outlook.com> - 8e3e502
- change restrip to rstrip

* Sun Oct 27 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 89d0254
- version 4.3.4

* Sun Oct 27 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c0ae9c8
- Bump required qubes-gui-common version

* Thu Oct 24 2024 Ali Mirjamali <ali@mirjamali.com> - b9aed51
- Improve clipboard .metadata parsing

* Mon Oct 21 2024 Ali Mirjamali <ali@mirjamali.com> - ed6ace4
- Switching CI to R4.3

* Mon Oct 21 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3792f81
- CI: switch to R4.3

* Mon Oct 21 2024 qubest <qubest.dev@outlook.com> - 655d34b
- Move rstrip before split

* Sun Oct 20 2024 Ali Mirjamali <ali@mirjamali.com> - 15b8f03
- Make maximum clipboard buffer lenght configurable

* Thu Oct 17 2024 Piotr Bartman-Szwarc <prbartman@invisiblethingslab.com> - c11aa04
- q-dev: cleanup mic.py

* Thu Oct 17 2024 qubest <qubest.dev@outlook.com> - fd5274b
- remove trailing \x00 The trailing \x00 in the request header make the domain name as follow (domain\x00). Which cause a bug when listing domains using qubesadminapi. This bug occured when the icon-receiver is running on guivm other than dom0.

* Thu Oct 17 2024 qubest <qubest.dev@outlook.com> - 9d3bcbc
- Update guivm service name

* Tue Oct 15 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5873084
- shmoverride: do not remove the shmid file if taking the lock fails

* Tue Oct 15 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1c5794d
- Add Xwayland wrapper similar to the one for Xorg

* Tue Oct 08 2024 Piotr Bartman-Szwarc <prbartman@invisiblethingslab.com> - 43d85da
- q-dev: mic auto-attach

* Tue Oct 08 2024 Piotr Bartman-Szwarc <prbartman@invisiblethingslab.com> - 602a4c8
- q-dev: add less confusing device_id of microphone

* Mon Sep 30 2024 Yaroslav Bolyukin <iam@lach.pw> - e7d4a0c
- fix: shmoverride hooks in presence of other constructors calling fstat

* Fri Sep 27 2024 Piotr Bartman-Szwarc <prbartman@invisiblethingslab.com> - 9008af8
- q-dev: update argument name device -> port

* Thu Sep 26 2024 Piotr Bartman-Szwarc <prbartman@invisiblethingslab.com> - 41d9bad
- q-dev: update argument name ident -> port_id

* Mon Aug 26 2024 Piotr Bartman-Szwarc <prbartman@invisiblethingslab.com> - deee25b
- q-dev: lint

* Tue Aug 20 2024 Piotr Bartman-Szwarc <prbartman@invisiblethingslab.com> - 751733c
- q-dev: cleanup

* Tue Aug 20 2024 Piotr Bartman-Szwarc <prbartman@invisiblethingslab.com> - 40fab96
- q-dev: port

* Mon Aug 12 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9966538
- version 4.3.3

* Mon Jul 22 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c6acd17
- Use QubesDB to authorize usage of mic and retrieve its status

* Fri Jul 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 28dc3e1
- version 4.3.2

* Fri Jul 05 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - cac038a
- Update lint job

* Fri Jul 05 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 660ac1b
- Reformat according to python-black

* Sat Jun 22 2024 Euwiiwueir <euweuwi2@onionmail.info> - 51399c3
- qubes-guid: add window_background_color setting

* Sat Jun 22 2024 Euwiiwueir <euweuwi2@onionmail.info> - 7e85df2
- Factor out a function to parse color from string

* Mon Jun 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 122f9b4
- version 4.3.1

* Sat Jun 15 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 68f8855
- version 4.3.0

* Fri Jun 14 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e585798
- Add basic SELinux policy

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - 2062be5
- q-dev: better description of mic

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - cd97c56
- q-dev: fix device protocol

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - 77609d8
- q-dev: device protocol

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - cef05f9
- q-dev: set Microphone Interface

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - 157b079
- q-dev: change `devclass` to be consistent with qubes-core-admin

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - e3e097e
- q-dev: reformat file + typos

* Sun Apr 28 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e5414b7
- version 4.2.7

* Fri Apr 26 2024 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - c4b92a0
- pacat-simple-vchan: improve cleanup

